@@ -1,6 +1,5 @@
 package Net::WHMCS::Base;
-$Net::WHMCS::Base::VERSION = '0.08';
-
+$Net::WHMCS::Base::VERSION = '0.09';
 # ABSTRACT: WHMCS API Role
 
 use Moo::Role;
@@ -8,38 +7,48 @@ use Carp 'croak';
 use LWP::UserAgent;
 use JSON;
 
-has 'WHMCS_URL'      => ( is => 'rw', required => 1 );
-has 'WHMCS_USERNAME' => ( is => 'rw', required => 1 );
-has 'WHMCS_PASSWORD' => ( is => 'rw', required => 1 );
-has 'WHMCS_API_ACCESSKEY' => ( is => 'rw' );
+has 'WHMCS_URL' => (
+    is       => 'rw',
+    required => 1
+);
+has 'WHMCS_USERNAME' => (
+    is       => 'rw',
+    required => 1
+);
+has 'WHMCS_PASSWORD' => (
+    is       => 'rw',
+    required => 1
+);
+has 'WHMCS_API_ACCESSKEY' => (is => 'rw');
 
-has 'ua' => ( is => 'lazy' );
+has 'ua' => (is => 'lazy');
 
 sub _build_ua {
     return LWP::UserAgent->new;
 }
 
 sub build_request {
-    my ( $self, $params ) = @_;
+    my ($self, $params) = @_;
 
-    if ( not exists $params->{action} ) {
+    if (not exists $params->{action}) {
         croak "No API action set\n";
     }
 
     $params->{username}  = $self->WHMCS_USERNAME;
     $params->{password}  = $self->WHMCS_PASSWORD;
-    $params->{accesskey} = $self->WHMCS_API_ACCESSKEY
-      if $self->WHMCS_API_ACCESSKEY;
+    $params->{accesskey} = $self->WHMCS_API_ACCESSKEY if $self->WHMCS_API_ACCESSKEY;
 
     $params->{responsetype} = 'json';
 
-    my $resp = $self->ua->post( $self->WHMCS_URL, $params );
-    return { result => 'error', message => $resp->status_line }
-      unless $resp->is_success;
+    my $resp = $self->ua->post($self->WHMCS_URL, $params);
+    return {
+        result  => 'error',
+        message => $resp->status_line
+    } unless $resp->is_success;
 
     # print Dumper(\$resp); use Data::Dumper;
 
-    return decode_json( $resp->content );
+    return decode_json($resp->content);
 }
 
 1;
@@ -56,7 +65,7 @@ Net::WHMCS::Base - WHMCS API Role
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head3 build_request
 
@@ -74,7 +83,7 @@ Fayland Lam <fayland@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Fayland Lam.
+This software is copyright (c) 2017 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
