@@ -1,6 +1,5 @@
 package Net::WHMCS::Miscellaneous;
-$Net::WHMCS::Miscellaneous::VERSION = '0.08';
-
+$Net::WHMCS::Miscellaneous::VERSION = '0.09';
 # ABSTRACT: WHMCS API Miscellaneous
 
 use Moo;
@@ -9,9 +8,9 @@ with 'Net::WHMCS::Base';
 use Carp 'croak';
 
 sub addproduct {
-    my ( $self, $params ) = @_;
-    $params->{action} = 'addproduct';
-    foreach my $r (qw/type gid name paytype/) {
+    my ($self, $params) = @_;
+    $params->{action} = 'AddProduct';
+    foreach my $r (qw/gid name/) {
         croak "$r is required." unless $params->{$r};
     }
     return $self->build_request($params);
@@ -31,7 +30,7 @@ Net::WHMCS::Miscellaneous - WHMCS API Miscellaneous
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head2 addproduct
 
@@ -45,7 +44,7 @@ version 0.08
 		...
 	});
 
-L<http://docs.whmcs.com/API:Add_Product>
+L<https://developers.whmcs.com/api-reference/addproduct/>
 
 =head1 AUTHOR
 
@@ -53,7 +52,7 @@ Fayland Lam <fayland@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Fayland Lam.
+This software is copyright (c) 2017 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
