@@ -1,14 +1,13 @@
 package Net::WHMCS::Support;
-$Net::WHMCS::Support::VERSION = '0.08';
-
+$Net::WHMCS::Support::VERSION = '0.09';
 # ABSTRACT: WHMCS API Support
 
 use Moo;
 with 'Net::WHMCS::Base';
 
 sub openticket {
-    my ( $self, $params ) = @_;
-    $params->{action} = 'openticket';
+    my ($self, $params) = @_;
+    $params->{action} = 'OpenTicket';
     return $self->build_request($params);
 }
 
@@ -26,7 +25,7 @@ Net::WHMCS::Support - WHMCS API Support
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head2 openticket
 
@@ -37,7 +36,7 @@ version 0.08
 		message => 'message'
 	});
 
-L<http://docs.whmcs.com/API:Open_Ticket>
+L<https://developers.whmcs.com/api-reference/openticket/>
 
 =head1 AUTHOR
 
@@ -45,7 +44,7 @@ Fayland Lam <fayland@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Fayland Lam.
+This software is copyright (c) 2017 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
